==> owncloud_7.0.0~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/eu.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Zure ezarpenak eguneratu dira.",
"Activity" => "Jarduera",
"A file or folder has been <strong>shared</strong>" => "Fitxategia edo karpeta <strong>konpartitu</strong> da",
"A new file or folder has been <strong>created</strong> in a shared folder" => "Fitxategi edo karpeta berria  <strong>sortu</strong> da konpartitutako karpetan",
"A file or folder has been <strong>changed</strong> in a shared folder" => "Fitxategia edo karpeta <strong>aldatu</strong> da konpartitutako karpetan",
"A file or folder has been <strong>deleted</strong> from a shared folder" => "Fitxategia edo karpeta  <strong>ezabatu</strong> da konpartitutako karpetan",
"You created %1\$s" => "Zuk sortua %1\$s",
"%2\$s created %1\$s" => "%2\$sk sortua %1\$s",
"You changed %1\$s" => "%1\$s aldatu duzu",
"%2\$s changed %1\$s" => "%2\$sk aldatuta %1\$s",
"You deleted %1\$s" => "%1\$s ezabatu duzu",
"%2\$s deleted %1\$s" => "%2\$sk ezabatuta %1\$s",
"You shared %1\$s with %2\$s" => "Zuk %1\$s elkarbanatu duzu %2\$srekin",
"You shared %1\$s with group %2\$s" => "Zuk %1\$s elkarbanatu duzu %2\$s taldearekin",
"%2\$s shared %1\$s with you" => "%2\$sk zurekin %1\$s elkarbanatu du",
"Activity notification" => "Jarduera jakinarazpenak",
"All Activities" => "Jarduera guztiak",
"Activities by you" => "Zure jarduerak",
"Activities by others" => "Besteen jarduerak",
"Shares" => "Partekatuak",
"Files" => "Fitxategiak",
"%s and %s" => "%s eta %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s eta <strong class=\"tooltip\" title=\"%s\">%n gehiago</strong>","%s eta <strong class=\"tooltip\" title=\"%s\">%n gehiago</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s eta %n gehiago","%s eta %n gehiago"),
"Hello %s," => "Kaixo %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Posta hau jaso duzu azkenengo orduan %sko hurrengo gertaerak direla eta",
"You are receiving this email because in the last day the following things happened at %s" => "Posta hau jaso duzu azkenengo egunean %sko hurrengo gertaerak direla eta",
"You are receiving this email because in the last week the following things happened at %s" => "Posta hau jaso duzu azkenengo astean %sko hurrengo gertaerak direla eta",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Gertaeren zerrenda bat ikusiko duzu zure %s erabiltzen hasten zarenean.",
"No more events to load" => "Ez dago kargatzeko gertaera gehiagorik",
"Enable RSS feed" => "Gaitu RSS jarioa",
"Notifications" => "Jakinarazpenak",
"Mail" => "Posta",
"Stream" => "Jarioa",
"You need to set up your email address before you can receive notification emails." => "Zure epostaren  zehaztu behar duzu jakinarazpen epostak jaso aurretik.",
"Send emails:" => "Bidali epostak:",
"Hourly" => "Orduro",
"Daily" => "Egunero",
"Weekly" => "Astero",
"Activity feed" => "Jarduera jarioa",
"Personal activity feed for %s" => "%sen jarduera jario pertsonala"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud_7.0.1~rc1%2Bdfsg.orig.tar.bz2: owncloud/apps/activity/l10n/eu.php <==
<?php
$TRANSLATIONS = array(
"Your settings have been updated." => "Zure ezarpenak eguneratu dira.",
"Activity" => "Jarduera",
"A file or folder has been <strong>shared</strong>" => "Fitxategia edo karpeta <strong>konpartitu</strong> da",
"A new file or folder has been <strong>created</strong>" => "Fitxategi edo karpeta berri bat <strong>sortu da</strong>",
"A file or folder has been <strong>changed</strong>" => "Fitxategi edo karpeta bat <strong>aldatu da</strong>",
"A file or folder has been <strong>deleted</strong>" => "Fitxategi edo karpeta bat <strong>ezabatu da</strong>",
"You created %1\$s" => "Zuk sortua %1\$s",
"%2\$s created %1\$s" => "%2\$sk sortua %1\$s",
"You changed %1\$s" => "%1\$s aldatu duzu",
"%2\$s changed %1\$s" => "%2\$sk aldatuta %1\$s",
"You deleted %1\$s" => "%1\$s ezabatu duzu",
"%2\$s deleted %1\$s" => "%2\$sk ezabatuta %1\$s",
"You shared %1\$s with %2\$s" => "Zuk %1\$s elkarbanatu duzu %2\$srekin",
"You shared %1\$s with group %2\$s" => "Zuk %1\$s elkarbanatu duzu %2\$s taldearekin",
"%2\$s shared %1\$s with you" => "%2\$sk zurekin %1\$s elkarbanatu du",
"You shared %1\$s via link" => "Konpartitu duzu %1\$s esteka baten bidez",
"Activity notification" => "Jarduera jakinarazpenak",
"All Activities" => "Jarduera guztiak",
"Activities by you" => "Zure jarduerak",
"Activities by others" => "Besteen jarduerak",
"Shares" => "Partekatuak",
"Files" => "Fitxategiak",
"%s and %s" => "%s eta %s",
", " => ", ",
"_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_::_%s and <strong class=\_tooltip\_ title=\_%s\_>%n more</strong>_" => array("%s eta <strong class=\"tooltip\" title=\"%s\">%n gehiago</strong>","%s eta <strong class=\"tooltip\" title=\"%s\">%n gehiago</strong>"),
"_%s and %n more_::_%s and %n more_" => array("%s eta %n gehiago","%s eta %n gehiago"),
"Hello %s," => "Kaixo %s,",
"You are receiving this email because in the last hour the following things happened at %s" => "Posta hau jaso duzu azkenengo orduan %sko hurrengo gertaerak direla eta",
"You are receiving this email because in the last day the following things happened at %s" => "Posta hau jaso duzu azkenengo egunean %sko hurrengo gertaerak direla eta",
"You are receiving this email because in the last week the following things happened at %s" => "Posta hau jaso duzu azkenengo astean %sko hurrengo gertaerak direla eta",
"* %s" => "* %s",
"You will see a list of events here when you start to use your %s." => "Gertaeren zerrenda bat ikusiko duzu zure %s erabiltzen hasten zarenean.",
"No more events to load" => "Ez dago kargatzeko gertaera gehiagorik",
"Enable RSS feed" => "Gaitu RSS jarioa",
"Notifications" => "Jakinarazpenak",
"Mail" => "Posta",
"Stream" => "Jarioa",
"Notify about my own actions" => "Notifikatu neure ekintzak",
"You need to set up your email address before you can receive notification emails." => "Zure epostaren  zehaztu behar duzu jakinarazpen epostak jaso aurretik.",
"Send emails:" => "Bidali epostak:",
"Hourly" => "Orduro",
"Daily" => "Egunero",
"Weekly" => "Astero",
"Activity feed" => "Jarduera jarioa",
"Personal activity feed for %s" => "%sen jarduera jario pertsonala"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
